Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 37016da8916aa86db6ae03b743334d1c47bfc4e4..d73a34ab262d8541c30e12b6d7701df9d0011b73 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -1997,11 +1997,14 @@ class JSReceiver: public HeapObject { |
MUST_USE_RESULT static Maybe<bool> HasInPrototypeChain( |
Isolate* isolate, Handle<JSReceiver> object, Handle<Object> proto); |
// Reads all enumerable own properties of source and adds them to target, |
// using either Set or CreateDataProperty depending on the use_set argument. |
MUST_USE_RESULT static Maybe<bool> SetOrCopyDataProperties( |
Isolate* isolate, Handle<JSReceiver> target, Handle<Object> source, |
- bool use_set); |
+ ScopedVector<Handle<Name>>* excluded_properties = nullptr, |
adamk
2017/01/17 19:56:33
Can this argument be a "const ScopedVector<...>*"?
gsathya
2017/01/17 21:59:23
Done.
|
+ bool use_set = true); |
// Implementation of [[HasProperty]], ECMA-262 5th edition, section 8.12.6. |
MUST_USE_RESULT static Maybe<bool> HasProperty(LookupIterator* it); |
@@ -1997,11 +1997,14 @@ class JSReceiver: public HeapObject { |
MUST_USE_RESULT static Maybe<bool> HasInPrototypeChain( |
Isolate* isolate, Handle<JSReceiver> object, Handle<Object> proto); |
- // Reads all enumerable own properties of source and adds them to target, |
- // using either Set or CreateDataProperty depending on the use_set argument. |
+ // Reads all enumerable own properties of source and adds them to |
+ // target, using either Set or CreateDataProperty depending on the |
+ // use_set argument. This only copies values not present in the |
+ // maybe_excluded_properties list. |
MUST_USE_RESULT static Maybe<bool> SetOrCopyDataProperties( |
Isolate* isolate, Handle<JSReceiver> target, Handle<Object> source, |